============
Installation
============

At the command line::

    pip install mqttcat

Another way is to use the mqtttool Docker container. Please see
the `Github repo`_.



.. _Github repo: https://github.com/martinvirtel/docker-mqtttool


